package org.act.wsc.bpel4wsmodeling.view.gui;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.util.HashMap;
import java.util.Map;
import java.util.ResourceBundle;
import javax.swing.BorderFactory;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;
import org.act.wsc.bpel4wsmodeling.projectdata.Project;
import org.act.wsc.bpel4wsmodeling.projectdata.listener.ILayerListener;
import org.act.wsc.bpel4wsmodeling.projectdata.process.GraphLayer;
import org.act.wsc.bpel4wsmodeling.projectdata.process.Layer;
import org.act.wsc.bpel4wsmodeling.projectdata.wsdl12define.WSDLLayer;
import org.act.wsc.bpel4wsmodeling.projectdata.wsdl12define.view.WSDLTreePane;
import org.act.wsc.bpel4wsmodeling.view.graphic.GraphLayerViewer;
import org.act.wsc.bpel4wsmodeling.view.graphic.GraphicToolBar;
import org.act.wsc.bpel4wsmodeling.view.graphic.LayerViewer;
import org.act.wsc.bpel4wsmodeling.view.resource.ResChoose;

public class EditPane extends JTabbedPane implements ILayerListener,
        MouseListener {
    Map layerToTab = new HashMap();
    Project project;
    public GraphicToolBar toolBar = null;
    ResourceBundle res = ResChoose.getLanguage();
    
    public EditPane(Project project) {
        super();
        this.project = project;
        this.project.addListener(this);
    }
    
    public void layerCreated(Layer layer) {
                JPanel jPanel = new JPanel();         jPanel.setLayout(new BorderLayout());
        JScrollPane jScrollPane;        String name = "";
        LayerViewerHolder holder = null;
        if (layer instanceof GraphLayer) {
            GraphLayer graphLayer = (GraphLayer) layer;
            LayerViewer layerViewer = new GraphLayerViewer(graphLayer);
            jScrollPane = new JScrollPane(layerViewer);
            if(graphLayer.getFigureProcess()!=null){
                                int viewportX=graphLayer.getFigureProcess().getX()-graphLayer.getFigureProcess().getStructWidth()/2;
                int viewportY=0;
                jScrollPane.getViewport().setViewPosition(new Point(viewportX,viewportY));
            }
            toolBar = new GraphicToolBar();
            holder = new LayerViewerHolder(layerViewer);
            holder.setLayout(new BorderLayout());
            holder.add(toolBar, BorderLayout.NORTH);
            holder.add(jScrollPane, BorderLayout.CENTER);
            name = res.getString("model");
        }
                else if (layer instanceof WSDLLayer) {
            WSDLLayer wsdlLayer = (WSDLLayer) layer;
            WSDLTreePane layerViewer = new WSDLTreePane(wsdlLayer);
            holder = new LayerViewerHolder(layerViewer);
            JScrollPane scrollPane = new JScrollPane(layerViewer);
            holder.setLayout(new BorderLayout());
            holder.add(scrollPane);
            name = layerViewer.getName();
        }
        if (holder != null) {
            this.layerToTab.put(layer,holder);
            this.addTab(name, holder);
            this.setSelectedComponent(holder);
        }
        this.setBorder(BorderFactory.createLineBorder(Color.white, 1));
    }
    
    public void layerOpened(Layer layer) {
                String name = "";
        LayerViewerHolder holder = (LayerViewerHolder) this.layerToTab
                .get(layer);
        if (holder != null) {
            if (layer instanceof GraphLayer) {
                name = res.getString("model");
            } else if (layer instanceof WSDLLayer) {
                name = ((WSDLTreePane) (holder.getLayerViewer())).getName();
            }
            int index = -1;
            if ((index = this.indexOfComponent(holder)) == -1) {
                this.addTab(name, holder);
            }
            this.setSelectedComponent(holder);
        }
            }
    
    public void layerClosed(Layer layer) {
        LayerViewerHolder holder;
        if((holder=(LayerViewerHolder) this.layerToTab.get(layer))!=null){
            this.remove(holder);
        }
      
    }
    
    public void layerRemoved(Layer layer) {
                LayerViewerHolder holder = (LayerViewerHolder) this.layerToTab.get(layer);
        this.layerToTab.remove(layer);
        this.remove(holder);
    }
    
    public void mouseClicked(MouseEvent e) {
                if (e.getButton() == 1 && e.getClickCount() == 1) {
            int index=this.indexAtLocation(e.getX(),e.getY());
            if(index!=-1){
                if(this.getComponentAt(index) instanceof LayerViewerHolder){
                    this.project.openLayer(((LayerViewerHolder)this.getComponentAt(index)).getLayerViewer().getLayer());
                }
            }
        }
    }
    
    public void mouseEntered(MouseEvent e) {
            }
    
    public void mouseExited(MouseEvent e) {
            }
    
    public void mousePressed(MouseEvent e) {
            }
    
    public void mouseReleased(MouseEvent e) {
            }
}
class LayerViewerHolder extends JPanel {
    LayerViewer layerViewer;
    
    public LayerViewerHolder(LayerViewer layerViewer) {
        super();
        this.layerViewer = layerViewer;
    }
    
    public LayerViewer getLayerViewer() {
        return layerViewer;
    }
}
